"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@jscpd/core");
const fs_extra_1 = require("fs-extra");
const safe_1 = require("colors/safe");
const path_1 = require("path");
const reports_1 = require("../utils/reports");
const table = require('markdown-table');
class MarkdownReporter {
    constructor(options) {
        this.options = options;
    }
    report(clones, statistic) {
        const report = `
# Copy/paste detection report

> Duplications detection: Found ${clones.length} exact clones with ${statistic.total.duplicatedLines}(${statistic.total.percentage}%) duplicated lines in ${statistic.total.sources} (${Object.keys(statistic.formats).length} formats) files.

${table([
            ['Format', 'Files analyzed', 'Total lines', 'Total tokens', 'Clones found', 'Duplicated lines', 'Duplicated tokens'],
            ...Object.keys(statistic.formats).map((format) => reports_1.convertStatisticToArray(format, statistic.formats[format].total)),
            reports_1.convertStatisticToArray('Total:', statistic.total).map(item => `**${item}**`)
        ])}
`;
        fs_extra_1.ensureDirSync(core_1.getOption('output', this.options));
        fs_extra_1.writeFileSync(core_1.getOption('output', this.options) + '/jscpd-report.md', report);
        console.log(safe_1.green(`Markdown report saved to ${path_1.join(this.options.output, 'jscpd-report.md')}`));
    }
}
exports.MarkdownReporter = MarkdownReporter;
//# sourceMappingURL=markdown.js.map